@@ -1,3 +1,6 @@
+import socket
+hostname = socket.gethostname()
+
 config = dict(
     # This is a dict of possible addresses from which fedmsg can send
     # messages.  fedmsg.init(...) requires that a 'name' argument be passed
@@ -11,13 +14,13 @@ config = dict(
         # name of it's calling module to determine which endpoint definition
         # to use.  This can be overridden by explicitly providing the name in
         # the initial call to fedmsg.init(...).
-        "bodhi.marat": ["tcp://*:3001"],
-        "fas.marat": ["tcp://*:3002"],
-        "fedoratagger.marat": ["tcp://*:3003"],
-        "mediawiki.marat": ["tcp://*:3004"],
-        "pkgdb.marat": ["tcp://*:3005"],
+        "bodhi.%s" % hostname: ["tcp://*:3001"],
+        "fas.%s" % hostname: ["tcp://*:3002"],
+        "fedoratagger.%s" % hostname: ["tcp://*:3003"],
+        "mediawiki.%s" % hostname: ["tcp://*:3004"],
+        "pkgdb.%s" % hostname: ["tcp://*:3005"],
 
-        "busmon.marat": ["tcp://*:3006"],
+        "busmon.%s" % hostname: ["tcp://*:3006"],
     },
 
     # This is the address of an active->passive relay.  It is used for the
