@@ -18,7 +18,7 @@ def _log_message(kw, message):
 
 extra_args = [
     (['--message'], {
-        'dest': 'message',
+        'dest': 'logger_message',
         'help': "The message to send.",
     }),
     (['--json-input'], {
@@ -66,8 +66,8 @@ def logger(**kwargs):
     kwargs['endpoints']['relay_inbound'] = kwargs['relay_inbound']
     fedmsg.init(name='relay_inbound', **kwargs)
 
-    if kwargs.get('message', None):
-        _log_message(kwargs, kwargs['message'])
+    if kwargs.get('logger_message'):
+        _log_message(kwargs, kwargs.get('logger_message'))
     else:
         line = sys.stdin.readline()
         while line:
