@@ -8,6 +8,8 @@ instance of the fedmsg-hub.
 
 import fedmsg
 from fedmsg.commands import command
+from fedmsg.consumers.relay import RelayConsumer
+from fedmsg.producers.heartbeat import HeartbeatProducer
 
 extra_args = []
 
@@ -29,4 +31,4 @@ def relay(**kw):
     kw['fedmsg.consumers.relay.enabled'] = True
 
     from moksha.hub import main
-    main(options=kw)
+    main(options=kw, consumers=[RelayConsumer], producers=[HeartbeatProducer])
