@@ -161,8 +161,13 @@ def _process_arguments(declared_args, doc, config):
 
 
 def _gather_configs_in(directory):
+    """ Return list of fully qualified python filenames in the given dir """
     try:
-        return [directory + fname for fname in os.listdir(directory)]
+        return [
+            directory + fname
+            for fname in os.listdir(directory)
+            if fname.endswith('.py')
+        ]
     except OSError:
         return []
 
